function [I_CaT,a_dT,b_dT,a_fT,b_fT] = update_I_CaT(con,V_m,d_T,f_T)
% T-type Ca2+ current (ICaT)
% The formulation of this current was taken from the Kurata model 2002.
% T-type calcium channels are low-voltage activated calcium channels that 
% open during membrane depolarization. These channels aid in mediating calcium 
% influx into cells after an action potential or depolarizing signal.
% 
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

I_CaT = con.C*con.g_CaT*(V_m-con.E_CaT)*d_T*f_T;

d_Tinf = 1/(1+exp(-(V_m+26.3)/6));
f_Tinf = 1/(1+exp((V_m+61.7)/5.6));
tho_dT = 1/(1.068*exp((V_m+26.3)/30)+1.068*exp(-(V_m+26.3)/30));
tho_fT = 1/(0.0153*exp(-(V_m+61.7)/83.3)+0.015*exp((V_m+61.7)/15.38));

a_dT = d_Tinf/tho_dT;
b_dT = (1-d_Tinf)/tho_dT;
a_fT = f_Tinf/tho_fT;
b_fT = (1-f_Tinf)/tho_fT;
end