function [I_KACh,a_w,b_w] = update_I_KACh(con,V_m,w)
% Acetylcholine-activated K+ current
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%
% References:
%
%   [1] Demir, Semahat S., John W. Clark, and Wayne R. Giles. 
%   "Parasympathetic modulation of sinoatrial node pacemaker activity in 
%   rabbit heart: a unifying model." American Journal of Physiology-Heart 
%   and Circulatory Physiology 276.6 (1999): H2221-H2244.
%
%   [2] Maltsev, Victor A., and Edward G. Lakatta. "A novel quantitative 
%   explanation for the autonomic modulation of cardiac pacemaker cell 
%   automaticity via a dynamic system of sarcolemmal and intracellular proteins." 
%   American Journal of Physiology-Heart and Circulatory Physiology 298.6 (2010): H2010-H2023.

I_KACh = con.C*w*con.g_KACh_max*(V_m-con.E_K);
beta_w = 0.001*12.32/(1+0.0042/(con.CCh*10^-6)); % CCh in mM
alpha_w = 0.001*17*exp(0.0133*(V_m+40));
w_inf = beta_w/(alpha_w+beta_w);
tho_w = 1/(alpha_w+beta_w);

a_w = w_inf/tho_w;
b_w = (1-w_inf)/tho_w;
end






