function [I_f,I_fNa,I_fK,a_y,b_y] = update_I_f(con,V_m,ac,y)
% Hyperpolarization-activated, “funny current (If)
%
% The formulation of I_f was taken from Kurata model 2002.
%
% The modulation of I_f by cAMP signaling was taken from:
%   DiFrancesco, Dario, and Paolo Tortora. "Direct activation of 
%   cardiac pacemaker channels by intracellular cyclic AMP." 
%   Nature 351.6322 (1991): 145-147.
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

V_shift = con.K_if*ac.cAMP^con.n_if/(con.K_05if^con.n_if+ac.cAMP^con.n_if)-18.76;

V_If12 = V_shift+con.V_If12;

y_inf = 1/(1+exp((V_m-V_If12)/13.5));
tho_y = 0.7166529/(exp(-(V_m+386.9)/45.302)+exp((V_m-73.08)/19.231));

I_fNa = con.C*0.3833*con.g_If*(V_m-con.E_Na)*y^2;
I_fK = con.C*0.6167*con.g_If*(V_m-con.E_K)*y^2;

a_y = y_inf/tho_y;
b_y = (1-y_inf)/tho_y;

I_f = I_fNa+I_fK;
end

